@@ -1,15 +1,17 @@
 import unittest
 import netCDF4
+import numpy as np
+from datetime import datetime, timedelta
 from numpy.testing import assert_array_almost_equal
 
 # test accessing data over http with opendap.
 
-URL = "http://remotetest.unidata.ucar.edu/thredds/dodsC/testdods/testData.nc"
-URL_https = 'https://podaac-opendap.jpl.nasa.gov/opendap/allData/modis/L3/aqua/11um/v2019.0/4km/daily/2017/365/AQUA_MODIS.20171231.L3m.DAY.NSST.sst.4km.nc'
-varname = 'Z_sfc'
-varmin = 0
-varmax = 3292
-varshape = (1,95,135)
+yesterday = datetime.utcnow() - timedelta(days=1)
+URL = f'http://nomads.ncep.noaa.gov/dods/gfs_1p00/gfs{yesterday:%Y%m%d}/gfs_1p00_00z'
+URL_https = 'https://www.neracoos.org/erddap/griddap/WW3_EastCoast_latest'
+varname = 'hgtsfc'
+data_min = -40; data_max = 5900
+varshape = (181, 360)
 
 class DapTestCase(unittest.TestCase):
 
@@ -24,14 +26,14 @@ class DapTestCase(unittest.TestCase):
         ncfile = netCDF4.Dataset(URL)
         assert varname in ncfile.variables.keys()
         var = ncfile.variables[varname]
-        assert var.shape == varshape
-        data = var[:]
-        assert_array_almost_equal(data.min(),varmin)
-        assert_array_almost_equal(data.max(),varmax)
+        data = var[0,...]
+        assert data.shape == varshape
+        assert(np.abs(data.min()-data_min) < 10)
+        assert(np.abs(data.max()-data_max) < 100)
         ncfile.close()
         # test https support (linked curl lib must built with openssl support)
         ncfile = netCDF4.Dataset(URL_https)
-        assert(ncfile['sst'].long_name=='Sea Surface Temperature')    
+        assert(ncfile['hs'].long_name=='Significant Wave Height')
         ncfile.close()
 
 if __name__ == '__main__':
