@@ -62,9 +62,9 @@ class TestgetStartCountStride(unittest.TestCase):
         elem = [slice(None), [1,3,5], 8]
         start, count, stride, put_ind = _StartCountStride(elem, (50, 6, 10))
         # pull request #683 now does not convert integer sequences to strided
-        # slices.
-        #assert_equal(put_ind[...,1].squeeze(), slice(None,None,None))
-        assert_equal(put_ind[...,1].squeeze(), [0,1,2])
+        # slices. PR #1224 reverts this behavior.
+        assert_equal(put_ind[...,1].squeeze(), slice(None,None,None))
+        #assert_equal(put_ind[...,1].squeeze(), [0,1,2])
 
 
     def test_multiple_sequences(self):
@@ -320,7 +320,7 @@ class TestsetStartCountStride(unittest.TestCase):
             #assert_equal(str(e), "At most one ellipsis allowed in a slicing expression")
             assert_equal(str(e), "list index out of range")
 
-class FakeGroup(object):
+class FakeGroup:
     """Create a fake group instance by passing a dictionary of booleans
     keyed by dimension name."""
     def __init__(self, dimensions):
@@ -328,7 +328,7 @@ class FakeGroup(object):
         for k,v in dimensions.items():
             self.dimensions[k] = FakeDimension(v)
 
-class FakeDimension(object):
+class FakeDimension:
     def __init__(self, unlimited=False):
         self.unlimited = unlimited
 
